@@ -6,9 +6,13 @@ PY2 = sys.version_info[0] == 2
 if not PY2:
     text_type = str
     string_types = (str,)
+    from collections import abc
+    from urllib.parse import urlparse
 else:
     text_type = unicode
     string_types = (str, unicode)
+    import collections as abc
+    from urlparse import urlparse
 
 
 def to_bytes(text):
@@ -30,4 +34,6 @@ class FlaskWTFDeprecationWarning(DeprecationWarning):
 
 
 warnings.simplefilter('always', FlaskWTFDeprecationWarning)
-warnings.filterwarnings('ignore', category=FlaskWTFDeprecationWarning, module='wtforms|flask_wtf')
+warnings.filterwarnings(
+    'ignore', category=FlaskWTFDeprecationWarning, module='wtforms|flask_wtf'
+)
